==> ui-0.2.43.tgz: package/lib/cjs/Chip/Chip.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var Styled = _interopRequireWildcard(require("./Chip.styled"));
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const CloseButton = _ref => {
  let {
    onClose
  } = _ref;
  return (0, _jsxRuntime.jsx)(Styled.CloseButtonWrapper, (0, _assign.default)({
    onClick: onClose,
    type: "button"
  }, {
    children: (0, _jsxRuntime.jsxs)("svg", (0, _assign.default)({
      width: "24",
      height: "24",
      viewBox: "0 0 24 24",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: [(0, _jsxRuntime.jsx)("circle", {
        cx: "12",
        cy: "12",
        r: "12",
        fill: "#C3C8D2"
      }), (0, _jsxRuntime.jsx)("path", {
        fillRule: "evenodd",
        clipRule: "evenodd",
        d: "M17.6569 6.34338C17.8668 6.55332 17.8668 6.89371 17.6569 7.10366L12.7603 12.0002L17.6569 16.8968C17.8668 17.1067 17.8668 17.4471 17.6569 17.6571C17.4469 17.867 17.1065 17.867 16.8966 17.6571L12 12.7605L7.10343 17.6571C6.89348 17.867 6.55309 17.867 6.34315 17.6571C6.1332 17.4471 6.1332 17.1067 6.34315 16.8968L11.2405 11.9995L6.34315 7.10366C6.1332 6.89371 6.1332 6.55332 6.34315 6.34338C6.55309 6.13343 6.89348 6.13343 7.10343 6.34338L12.0008 11.2392L16.8966 6.34338C17.1065 6.13343 17.4469 6.13343 17.6569 6.34338Z",
        fill: "#FEFEFE"
      }), (0, _jsxRuntime.jsx)("mask", (0, _assign.default)({
        id: "mask0_2747_48362",
        style: {
          maskType: 'alpha'
        },
        maskUnits: "userSpaceOnUse",
        x: "6",
        y: "6",
        width: "12",
        height: "12"
      }, {
        children: (0, _jsxRuntime.jsx)("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M17.6569 6.34338C17.8668 6.55332 17.8668 6.89371 17.6569 7.10366L12.7603 12.0002L17.6569 16.8968C17.8668 17.1067 17.8668 17.4471 17.6569 17.6571C17.4469 17.867 17.1065 17.867 16.8966 17.6571L12 12.7605L7.10343 17.6571C6.89348 17.867 6.55309 17.867 6.34315 17.6571C6.1332 17.4471 6.1332 17.1067 6.34315 16.8968L11.2405 11.9995L6.34315 7.10366C6.1332 6.89371 6.1332 6.55332 6.34315 6.34338C6.55309 6.13343 6.89348 6.13343 7.10343 6.34338L12.0008 11.2392L16.8966 6.34338C17.1065 6.13343 17.4469 6.13343 17.6569 6.34338Z",
          fill: "white"
        })
      })), (0, _jsxRuntime.jsx)("g", {
        mask: "url(#mask0_2747_48362)"
      })]
    }))
  }));
};
const Chip = /*#__PURE__*/_react.default.forwardRef((_a, ref) => {
  var {
      text,
      closeable = false,
      onClose = () => {
        console.log();
      }
    } = _a,
    rest = __rest(_a, ["text", "closeable", "onClose"]);
  return (0, _jsxRuntime.jsxs)(Styled.DSChipWrapper, (0, _assign.default)({
    ref: ref
  }, rest, {
    children: [(0, _jsxRuntime.jsx)(Styled.Text, (0, _assign.default)({
      "$closeable": closeable
    }, {
      children: text
    })), closeable && (0, _jsxRuntime.jsx)(CloseButton, {
      onClose: onClose
    })]
  }));
});
var _default = /*#__PURE__*/_react.default.memo(Chip);
exports.default = _default;

==> ui-0.2.52.tgz: package/lib/cjs/Chip/Chip.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var Styled = _interopRequireWildcard(require("./Chip.styled"));
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const CloseButton = _ref => {
  let {
    onClose
  } = _ref;
  return (0, _jsxRuntime.jsx)(Styled.CloseButtonWrapper, (0, _assign.default)({
    onClick: onClose,
    type: "button"
  }, {
    children: (0, _jsxRuntime.jsxs)("svg", (0, _assign.default)({
      width: "24",
      height: "24",
      viewBox: "0 0 24 24",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: [(0, _jsxRuntime.jsx)("circle", {
        cx: "12",
        cy: "12",
        r: "12",
        fill: "#C3C8D2"
      }), (0, _jsxRuntime.jsx)("path", {
        fillRule: "evenodd",
        clipRule: "evenodd",
        d: "M17.6569 6.34338C17.8668 6.55332 17.8668 6.89371 17.6569 7.10366L12.7603 12.0002L17.6569 16.8968C17.8668 17.1067 17.8668 17.4471 17.6569 17.6571C17.4469 17.867 17.1065 17.867 16.8966 17.6571L12 12.7605L7.10343 17.6571C6.89348 17.867 6.55309 17.867 6.34315 17.6571C6.1332 17.4471 6.1332 17.1067 6.34315 16.8968L11.2405 11.9995L6.34315 7.10366C6.1332 6.89371 6.1332 6.55332 6.34315 6.34338C6.55309 6.13343 6.89348 6.13343 7.10343 6.34338L12.0008 11.2392L16.8966 6.34338C17.1065 6.13343 17.4469 6.13343 17.6569 6.34338Z",
        fill: "#FEFEFE"
      }), (0, _jsxRuntime.jsx)("mask", (0, _assign.default)({
        id: "mask0_2747_48362",
        style: {
          maskType: 'alpha'
        },
        maskUnits: "userSpaceOnUse",
        x: "6",
        y: "6",
        width: "12",
        height: "12"
      }, {
        children: (0, _jsxRuntime.jsx)("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M17.6569 6.34338C17.8668 6.55332 17.8668 6.89371 17.6569 7.10366L12.7603 12.0002L17.6569 16.8968C17.8668 17.1067 17.8668 17.4471 17.6569 17.6571C17.4469 17.867 17.1065 17.867 16.8966 17.6571L12 12.7605L7.10343 17.6571C6.89348 17.867 6.55309 17.867 6.34315 17.6571C6.1332 17.4471 6.1332 17.1067 6.34315 16.8968L11.2405 11.9995L6.34315 7.10366C6.1332 6.89371 6.1332 6.55332 6.34315 6.34338C6.55309 6.13343 6.89348 6.13343 7.10343 6.34338L12.0008 11.2392L16.8966 6.34338C17.1065 6.13343 17.4469 6.13343 17.6569 6.34338Z",
          fill: "white"
        })
      })), (0, _jsxRuntime.jsx)("g", {
        mask: "url(#mask0_2747_48362)"
      })]
    }))
  }));
};
const Chip = /*#__PURE__*/_react.default.forwardRef((_a, ref) => {
  var {
      text,
      closeable = false,
      onClose = () => {
        console.log();
      }
    } = _a,
    rest = __rest(_a, ["text", "closeable", "onClose"]);
  return (0, _jsxRuntime.jsxs)(Styled.DSChipWrapper, (0, _assign.default)({
    ref: ref
  }, rest, {
    children: [(0, _jsxRuntime.jsx)(Styled.Text, (0, _assign.default)({
      "$closeable": closeable
    }, {
      children: text
    })), closeable && (0, _jsxRuntime.jsx)(CloseButton, {
      onClose: onClose
    })]
  }));
});
var _default = exports.default = /*#__PURE__*/_react.default.memo(Chip);
